==> segatex-5.00.tgz: segatex-5.00/src/semanage_core_fcontext_process.h <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2008 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef SEMANAGECOREFCONTEXTPROCESS_H
#define SEMANAGECOREFCONTEXTPROCESS_H

#include <qdialog.h>
#include <qlayout.h>
#include <qdir.h> 
#include <qregexp.h> 
#include <qlabel.h> 
#include <qtextedit.h>


class QLayout;
class QTextEdit;
class QLineEdit;
class QPushButton;

class SemanageCoreFcontextProcess: public QDialog 
{
	Q_OBJECT
public:
	SemanageCoreFcontextProcess(QWidget *parent = 0, const char *name = 0);
public slots:
signals:
//	void semanage_core_fcontext_prosess_close_button_clicked();
protected:
private slots:
	void semanage_core_base_fcontext_process();
	//void close_button_clicked();
	void add_button_clicked();
	void delete_button_clicked();
	void modify_button_clicked();
	void add_button_clicked_process(QString textEdit1_str, QString textEdit2_str);
	void delete_button_clicked_process(QString textEdit3_str);
	void modify_button_clicked_process(QString textEdit4_str, QString textEdit5_str);
	void readFromOutputFile();
public:
private:
	QPushButton *addButton;
	QPushButton *deleteButton;
	QPushButton *modifyButton;
	QPushButton *closeButton;
	QTextEdit *textEdit1;

	QVBoxLayout *mainLayout;
	QVBoxLayout *upperLayout;
	QVBoxLayout *underLayout;
	QHBoxLayout *leftLayout;
	QHBoxLayout *rightLayout;
	QHBoxLayout *thirdLayout;
	QVBoxLayout *middleLayout;
	QHBoxLayout *footLayout;

        QDir dir;
        QString path;
        QString name;
        QString dir_name;
        QString forward_slash;
        QString file_interface_name;
        QString line_analized;
        QString outputfile_str;

        QStringList::Iterator it_d;
        QStringList files;

        QString radiobutton_obj_str;
        QLabel *semanageEditLabel;
        QLabel *semanageEditLabel2;
        QLabel *semanageEditLabel3;
        QLabel *semanageEditLabel4;
        QLabel *semanageEditLabel5;
        QLineEdit *semanageEditLineEdit;
        QLineEdit *semanageEditLineEdit2;
        QLineEdit *semanageEditLineEdit3;
        QLineEdit *semanageEditLineEdit4;
        QLineEdit *semanageEditLineEdit5;
        QString semanageEditLineEdit_str;
        QString semanageEditLineEdit2_str;
        QString semanageEditLineEdit3_str;
        QString semanageEditLineEdit4_str;
        QString semanageEditLineEdit5_str;
	QString semanageEditLineEdit2_str_for_check;
	QString semanageEditLineEdit3_str_for_check;
	QString semanageEditLineEdit5_str_for_check;
        QString semanageEditLineEdit_str_pp;
        QString semanageEditLineEdit_str_add_restorecon;
        QString s_first;
        QString s_first_for_restorecon_str;
        QString s_second;
        QString s_second_for_restorecon_str;
        QString s_third;
        QString s_third_for_restorecon_str;
        QString s_fourth;
        QString s_fourth_for_restorecon_str;
        QString restorecon_str;
};

#endif

==> segatex-6.10.tgz: segatex-6.10/src/semanage_core_fcontext_process.h <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2008 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef SEMANAGECOREFCONTEXTPROCESS_H
#define SEMANAGECOREFCONTEXTPROCESS_H

#include <qdialog.h>
#include <qlayout.h>
#include <qdir.h> 
#include <qregexp.h> 
#include <qlabel.h> 
#include <qtextedit.h>
#include <qbuttongroup.h>
#include <qradiobutton.h>


class QLayout;
class QLineEdit;
class QPushButton;

class SemanageCoreFcontextProcess: public QDialog 
{
	Q_OBJECT
public:
	SemanageCoreFcontextProcess(QWidget *parent = 0, const char *name = 0);
public slots:
signals:
//	void semanage_core_fcontext_prosess_close_button_clicked();
protected:
private slots:
	void semanage_core_base_fcontext_process();
	//void close_button_clicked();
	void add_button_clicked();
	void delete_button_clicked();
	void modify_button_clicked();
	void add_button_clicked_process(QString textEdit1_str, QString textEdit2_str, QString textEdit7_str);
	void delete_button_clicked_process(QString textEdit3_str, QString textEdit6_str, QString textEdit8_str);
	void modify_button_clicked_process(QString textEdit4_str, QString textEdit5_str, QString textEdit9_str);
	void readFromOutputFile();
public:
private:
	QButtonGroup *filetypeButtonGroup;
	QPushButton *addButton;
	QPushButton *deleteButton;
	QPushButton *modifyButton;
	QPushButton *closeButton;
	QTextEdit *textEdit1;
	QRadioButton *allfilesRadioButton;
	QRadioButton *regularfileRadioButton;
	QRadioButton *directoryRadioButton;
	QRadioButton *blockdeviceRadioButton;
	QRadioButton *characterdeviceRadioButton;
	QRadioButton *socketRadioButton;
	QRadioButton *symboliclinkRadioButton;
	QRadioButton *namedpipeRadioButton;

	QVBoxLayout *mainLayout;
	QVBoxLayout *upperLayout;
	QVBoxLayout *underLayout;
	QHBoxLayout *leftLayout;
	QHBoxLayout *rightLayout;
	QHBoxLayout *thirdLayout;
	QHBoxLayout *fourthLayout;
	QVBoxLayout *middleLayout;
	QHBoxLayout *footLayout;

        QDir dir;
        QString path;
        QString name;
        QString dir_name;
        QString forward_slash;
        QString file_interface_name;
        QString line_analized;
        QString outputfile_str;

        QStringList::Iterator it_d;
        QStringList files;

        QString radiobutton_obj_str;
        QLabel *semanageEditLabel;
        QLabel *semanageEditLabel2;
        QLabel *semanageEditLabel3;
        QLabel *semanageEditLabel4;
        QLabel *semanageEditLabel5;
        QLabel *semanageEditLabel6;
        QLabel *semanageEditLabel7;
        QLabel *semanageEditLabel8;
        QLabel *semanageEditLabel9;
        QLineEdit *semanageEditLineEdit;
        QLineEdit *semanageEditLineEdit2;
        QLineEdit *semanageEditLineEdit3;
        QLineEdit *semanageEditLineEdit4;
        QLineEdit *semanageEditLineEdit5;
        QLineEdit *semanageEditLineEdit6;
        QLineEdit *semanageEditLineEdit7;
        QLineEdit *semanageEditLineEdit8;
        QLineEdit *semanageEditLineEdit9;
        QString semanageEditLineEdit_str;
        QString semanageEditLineEdit2_str;
        QString semanageEditLineEdit3_str;
        QString semanageEditLineEdit4_str;
        QString semanageEditLineEdit5_str;
        QString semanageEditLineEdit6_str;
        QString semanageEditLineEdit7_str;
        QString semanageEditLineEdit8_str;
        QString semanageEditLineEdit9_str;
	QString semanageEditLineEdit2_str_for_check;
	QString semanageEditLineEdit5_str_for_check;
	QString semanageEditLineEdit6_str_for_check;
        QString semanageEditLineEdit_str_pp;
        QString semanageEditLineEdit_str_add_restorecon;
        QString semanageEditLineEdit_str_delete_restorecon;
        QString semanageEditLineEdit_str_modify_restorecon;
        QString s_first;
        QString s_first_for_restorecon_str;
        QString s_second;
        QString s_second_for_restorecon_str;
        QString s_third;
        QString s_third_for_restorecon_str;
        QString s_fourth;
        QString s_fourth_for_restorecon_str;
        QString restorecon_str;
        QString restorecon_str_first;
        QString restorecon_str_second;
        QString restorecon_str_third;
        QString restorecon_str_fourth;
};

#endif
